export declare type OutputType = {
    data?: {
        "text/plain"?: string[];
        "text/html"?: string[];
        "text/latex"?: string[];
        "image/png"?: string;
        "image/jpeg"?: string;
        "image/gif"?: string;
        "application/javascript"?: string[];
    };
    output_type?: string;
    png?: string;
    jpeg?: string;
    gif?: string;
    text?: string[];
    execution_count?: number;
    metadata?: {
        scrolled?: boolean;
    };
};
export declare type CellType = {
    attachments?: {
        [s: string]: {
            [s: string]: string;
        };
    };
    cell_type?: string;
    execution_count?: number | null;
    prompt_number?: number;
    auto_number?: number;
    source?: string[];
    outputs?: OutputType[];
    input?: string[];
};
export declare type SyntaxThemeType = "atomDark" | "cb" | "coy" | "darcula" | "dark" | "duotoneDark" | "duotoneEarth" | "duotoneForest" | "duotoneLight" | "duotoneSea" | "duotoneSpace" | "funky" | "ghcolors" | "hopscotch" | "okaidia" | "pojoaque" | "prism" | "solarizedlight" | "tomorrow" | "twilight" | "vscDarkPlus" | "xonokai";
export declare type LanguageType = "python" | "r" | "julia";
export declare type BaseProps = {
    ipynb: {
        cells: CellType[];
        nbformat: 3 | 4 | 5;
        worksheets?: {
            cells: CellType[];
        }[];
    };
    syntaxTheme?: SyntaxThemeType;
    language?: LanguageType;
    bgTransparent?: boolean;
    mdiOptions?: MarkdownItOptions;
};
export declare type Props = BaseProps & {
    formulaOptions?: FormulaOptionsForMathjax;
};
export declare const IpynbRenderer: React.FC<Props>;
export declare type Props = BaseProps & {
    formulaOptions?: FormulaOptionsForKatex;
};
export declare const IpynbRenderer: React.FC<Props>;
export declare type CellProps = {
    cell: CellType;
    syntaxTheme: SyntaxThemeType;
    language: LanguageType;
    bgTransparent: boolean;
    formulaOptions?: any;
    mdiOptions: MarkdownItOptions;
    Markdown: React.FC<{
        text: string;
        formulaOptions: any;
        mdiOptions: MarkdownItOptions;
    }>;
};
export declare const defaultFormulaRenderer = "katex";
export declare const Cell: React.FC<CellProps>;
export declare type FormulaOptionsForKatex = {
    texmath?: {
        engine?: any;
        delimiters?: "dollars" | "brackets" | "doxygen" | "gitlab" | "julia" | "kramdown" | "beg_end";
        katexOptions?: KatexOptions;
    };
};
export declare type MarkdownProps = {
    text: string;
    formulaOptions: FormulaOptionsForKatex;
    mdiOptions: MarkdownItOptions;
};
export declare const MarkdownForKatex: React.FC<MarkdownProps>;
export declare type FormulaOptionsForMathjax = {
    mathjax3?: {
        tex?: any;
        svg?: any;
    };
};
export declare type MarkdownProps = {
    text: string;
    formulaOptions: FormulaOptionsForMathjax;
    mdiOptions: MarkdownItOptions;
};
export declare const MarkdownForMathjax: React.FC<MarkdownProps>;